spannertools.MeasuredComplexBeam
================================

.. abjad-lineage:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam

.. autoclass:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.append
      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.append_left
      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.components
      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.detach
      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.direction
      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.extend
      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.extend_left
      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.fracture
      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.fuse
      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.get_duration
      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.get_timespan
      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.index
      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.is_beamable_component
      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.leaves
      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.lone
      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.pop
      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.pop_left
      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.span
      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.__contains__
      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.__copy__
      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.__eq__
      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.__format__
      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.__getitem__
      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.__len__
      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.__lt__
      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.__ne__
      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.__repr__

Bases
-----

- :py:class:`spannertools.ComplexBeam <abjad.tools.spannertools.ComplexBeam.ComplexBeam>`

- :py:class:`spannertools.Beam <abjad.tools.spannertools.Beam.Beam>`

- :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.leaves
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.direction
   :noindex:

.. autoattribute:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.lone
   :noindex:

.. autoattribute:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.span
   :noindex:

Methods
-------

.. automethod:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.append
   :noindex:

.. automethod:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.append_left
   :noindex:

.. automethod:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.detach
   :noindex:

.. automethod:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.extend
   :noindex:

.. automethod:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.extend_left
   :noindex:

.. automethod:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.fracture
   :noindex:

.. automethod:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.fuse
   :noindex:

.. automethod:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.get_duration
   :noindex:

.. automethod:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.get_timespan
   :noindex:

.. automethod:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.index
   :noindex:

.. automethod:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.pop
   :noindex:

.. automethod:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.pop_left
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.is_beamable_component
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.__copy__
   :noindex:

.. automethod:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.__format__
   :noindex:

.. automethod:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam.__repr__
   :noindex:
